==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/tr.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Kendi okuma izninizi kaldıramazsınız.",
    "Team folders" : "Takım klasörleri",
    "Admin configured folders shared with everyone in a team" : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Takım klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç takım için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir. \nHub 10/Nextcloud 31 sürümünden başlayarak, yöneticinin bir takım klasörü atayabilmesi için takımın üyesi olması gereklidir.",
    "Unset" : "Ayarı kaldır",
    "Denied (Inherited permission)" : "Reddedildi (devralınan izin)",
    "Allowed (Inherited permission)" : "İzin verildi (devralınan izin)",
    "Denied" : "Reddedildi",
    "Allowed" : "İzin verildi",
    "Access denied" : "Erişim reddedildi",
    "Access allowed" : "Erişim izni verildi",
    "Inherit permission" : "İzinler devralınsın",
    "Deny" : "Reddet",
    "Allow" : "İzin ver",
    "Group" : "Grup",
    "Team" : "Takım",
    "Team folder" : "Takım klasörü",
    "Read" : "Okuma",
    "Write" : "Yazma",
    "Create" : "Ekleme",
    "Delete" : "Silme",
    "Share" : "Paylaşma",
    "You" : "Siz",
    "Remove access rule" : "Erişim kuralını sil",
    "Add advanced permission rule" : "Gelişmiş izin kuralı ekle",
    "Select a user or group" : "Bir kullanıcı ya da grup seçin",
    "Open Team folder" : "Takım klasörünü aç",
    "Permission denied. User does not have sufficient permissions." : "İzin verilmedi. Kullanıcının yeterli izinleri yok.",
    "Unexpected status from server" : "Sunucudan beklenmeyen bir durum bildirimi alındı",
    "List of Team folders." : "Takım klasörleri listesi.",
    "No Team folders yet" : "Henüz bir takım klasörü yok.",
    "Team folders will show up here" : "Takım klasörleri burada görüntülenir",
    "Add group" : "Grup ekle",
    "Default" : "Varsayılan",
    "Unlimited" : "Sınırsız",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "\"{folderName}\" klasörünü içindeki tüm dosyalarla birlikte silmek istediğinize emin misiniz? Bu işlem geri alınamaz",
    "Delete \"{folderName}\"?" : "\"{folderName}\" silinsin mi?",
    "Team folder admin delegation" : "Takım klasörü yönetici ataması",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud, Takım klasörlerinin yönetimini yönetici olmayan kullanıcılara devretmenize izin verir.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Takım klasörlerini yönetmesine ve API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will have access to all Team folders." : "Tüm takım klasörlerine erişebilirler.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Takım klasörlerini yönetmesine ve yalnızca API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will only have access to Team folders for which they have advanced permissions." : "Yalnızca gelişmiş izinlerine sahip oldukları takım klasörlerine erişebilirler.",
    "Group or team" : "Grup ya da takım",
    "Sort by number of groups or teams that have access to this folder" : "Bu klasöre erişimi olan grup veya takım sayısına göre sırala",
    "Sort by number of groups that have access to this folder" : "Bu klasöre erişimi olan grup sayısına göre sırala",
    "Folder name" : "Klasör adı",
    "Quota" : "Kota",
    "Advanced Permissions" : "Gelişmiş izinler",
    "Pagination of team folders" : "Takım klasörleri sayfalaması",
    "Previous" : "Önceki",
    "Next" : "Sonraki",
    "User" : "Kullanıcı",
    "Unknown" : "Bilinmiyor",
    "Users/groups that can manage" : "Yönetilebilecek kullanıcılar ve gruplar",
    "None" : "Yok",
    "No other groups or teams available" : "Kullanılabilecek başka bir grup ya da takım yok",
    "No other groups available" : "Kullanılabilecek başka bir grup yok",
    "{displayName} (team)" : "{displayName} (takım)",
    "Add group or team" : "Grup ya da takım ekle",
    "{size} used" : "{size} kullanılmış",
    "Other …" : "Diğer…",
    "You can not remove your own read permission." : "Kendi okuma izninizi kaldıramazsınız.",
    "Group folders" : "Grup klasörleri",
    "Admin configured folders shared with everyone in a group" : "Yönetici tarafından yapılandırılmış, gruptaki herkes ile paylaşılan klasörler",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Yönetici tarafından yapılandırılmış, gruptaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Grup klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç grup için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir.",
    "Group folder" : "Grup klasörü",
    "Open group folder" : "Grup klasörünü aç",
    "List of group folders." : "Grup klasörleri listesi.",
    "No group folders yet" : "Henüz bir grup klasörü yok",
    "Group folders will show up here" : "Grup klasörleri burada görüntülenir",
    "Group folder admin delegation" : "Grup klasörü yönetici ataması",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud, Grup klasörlerinin yönetimini yönetici olmayan kullanıcılara devretmenize izin verir.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Grup klasörlerini yönetmesine ve API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will have access to all group folders." : "Tüm grup klasörlerine erişebilirler.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Grup klasörlerini yönetmesine ve yalnızca API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will only have access to group folders for which they have advanced permissions." : "Yalnızca gelişmiş izinlerine sahip oldukları grup klasörlerine erişebilirler.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Takım klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç takım için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir."
},
"nplurals=2; plural=(n > 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/tr.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Kendi okuma izninizi kaldıramazsınız.",
    "Team folders" : "Takım klasörleri",
    "Unset" : "Ayarı kaldır",
    "Denied (Inherited permission)" : "Reddedildi (devralınan izin)",
    "Allowed (Inherited permission)" : "İzin verildi (devralınan izin)",
    "Denied" : "Reddedildi",
    "Allowed" : "İzin verildi",
    "Access denied" : "Erişim reddedildi",
    "Access allowed" : "Erişim izni verildi",
    "Inherit permission" : "İzinler devralınsın",
    "Deny" : "Reddet",
    "Allow" : "İzin ver",
    "Group" : "Grup",
    "Team" : "Takım",
    "Team folder" : "Takım klasörü",
    "Read" : "Okuma",
    "Write" : "Yazma",
    "Create" : "Ekleme",
    "Delete" : "Silme",
    "Share" : "Paylaşma",
    "You" : "Siz",
    "Remove access rule" : "Erişim kuralını sil",
    "Add advanced permission rule" : "Gelişmiş izin kuralı ekle",
    "Select a user or group" : "Bir kullanıcı ya da grup seçin",
    "Open Team folder" : "Takım klasörünü aç",
    "Permission denied. User does not have sufficient permissions." : "İzin verilmedi. Kullanıcının yeterli izinleri yok.",
    "Unexpected status from server" : "Sunucudan beklenmeyen bir durum bildirimi alındı",
    "List of Team folders." : "Takım klasörleri listesi.",
    "No Team folders yet" : "Henüz bir takım klasörü yok.",
    "Team folders will show up here" : "Takım klasörleri burada görüntülenir",
    "Add group" : "Grup ekle",
    "Default" : "Varsayılan",
    "Unlimited" : "Sınırsız",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "\"{folderName}\" klasörünü içindeki tüm dosyalarla birlikte silmek istediğinize emin misiniz? Bu işlem geri alınamaz",
    "Delete \"{folderName}\"?" : "\"{folderName}\" silinsin mi?",
    "Team folder admin delegation" : "Takım klasörü yönetici ataması",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud, Takım klasörlerinin yönetimini yönetici olmayan kullanıcılara devretmenize izin verir.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Takım klasörlerini yönetmesine ve API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will have access to all Team folders." : "Tüm takım klasörlerine erişebilirler.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Takım klasörlerini yönetmesine ve yalnızca API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will only have access to Team folders for which they have advanced permissions." : "Yalnızca gelişmiş izinlerine sahip oldukları takım klasörlerine erişebilirler.",
    "Group or team" : "Grup ya da takım",
    "Sort by number of groups or teams that have access to this folder" : "Bu klasöre erişimi olan grup veya takım sayısına göre sırala",
    "Sort by number of groups that have access to this folder" : "Bu klasöre erişimi olan grup sayısına göre sırala",
    "Folder name" : "Klasör adı",
    "Quota" : "Kota",
    "Advanced Permissions" : "Gelişmiş izinler",
    "Pagination of team folders" : "Takım klasörleri sayfalaması",
    "Previous" : "Önceki",
    "Next" : "Sonraki",
    "User" : "Kullanıcı",
    "Unknown" : "Bilinmiyor",
    "Users/groups that can manage" : "Yönetilebilecek kullanıcılar ve gruplar",
    "None" : "Yok",
    "No other groups or teams available" : "Kullanılabilecek başka bir grup ya da takım yok",
    "No other groups available" : "Kullanılabilecek başka bir grup yok",
    "{displayName} (team)" : "{displayName} (takım)",
    "Add group or team" : "Grup ya da takım ekle",
    "{size} used" : "{size} kullanılmış",
    "Other …" : "Diğer…",
    "You can not remove your own read permission." : "Kendi okuma izninizi kaldıramazsınız.",
    "Group folders" : "Grup klasörleri",
    "Admin configured folders shared with everyone in a group" : "Yönetici tarafından yapılandırılmış, gruptaki herkes ile paylaşılan klasörler",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Yönetici tarafından yapılandırılmış, gruptaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Grup klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç grup için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir.",
    "Group folder" : "Grup klasörü",
    "Open group folder" : "Grup klasörünü aç",
    "List of group folders." : "Grup klasörleri listesi.",
    "No group folders yet" : "Henüz bir grup klasörü yok",
    "Group folders will show up here" : "Grup klasörleri burada görüntülenir",
    "Group folder admin delegation" : "Grup klasörü yönetici ataması",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud, Grup klasörlerinin yönetimini yönetici olmayan kullanıcılara devretmenize izin verir.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Grup klasörlerini yönetmesine ve API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will have access to all group folders." : "Tüm grup klasörlerine erişebilirler.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Grup klasörlerini yönetmesine ve yalnızca API/REST kullanmasına izin verilecek grupları aşağıda belirtin.",
    "They will only have access to group folders for which they have advanced permissions." : "Yalnızca gelişmiş izinlerine sahip oldukları grup klasörlerine erişebilirler.",
    "Admin configured folders shared with everyone in a team" : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Takım klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç takım için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Yönetici tarafından yapılandırılmış, takımdaki herkes ile paylaşılan klasörler.\n\nKlasörler, Yönetici ayarları *Takım klasörleri* bölümünden yapılandırılabilir.\n\nBir klasör oluşturulduktan sonra, yöneticiler klasöre bir ya da bir kaç takım için erişim, yazma ve paylaşım izinleri ile klasör boyutu kotasını ayarlayabilir. \nHub 10/Nextcloud 31 sürümünden başlayarak, yöneticinin bir takım klasörü atayabilmesi için takımın üyesi olması gereklidir."
},
"nplurals=2; plural=(n > 1);");
